@@ -8,20 +8,22 @@
    Author: Paul Hardy, unifoundry <at> unifoundry.com, December 2007
    
    
-    Copyright (C) 2007-2008 Paul Hardy
+   Copyright (C) 2007, 2008, 2013 Paul Hardy
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   LICENSE:
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+      This program is free software: you can redistribute it and/or modify
+      it under the terms of the GNU General Public License as published by
+      the Free Software Foundation, either version 2 of the License, or
+      (at your option) any later version.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+      This program is distributed in the hope that it will be useful,
+      but WITHOUT ANY WARRANTY; without even the implied warranty of
+      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+      GNU General Public License for more details.
+
+      You should have received a copy of the GNU General Public License
+      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -120,18 +122,37 @@ int main(int argc, char *argv[]) {
    }
    /*
       Initialize selected code points for double width (16x16).
-      0 ==> 8 pixels wide; 1 ==> 16 pixels wide.
+      Double-width is forced in cases where a glyph (usually a combining
+      glyph) only occupies the left-hand side of a 16x16 grid, but must
+      be rendered as double-width to appear properly with other glyphs
+      in a given script.  If additions were made to a script after
+      Unicode 5.0, the Unicode version is given in parentheses after
+      the script name.
    */
-   for (i = 0x1100; i <= 0x11FF; i++) wide[i] = 1; /* Hangul Jamo */
-   for (i = 0x2580; i <= 0x259F; i++) wide[i] = 1; /* Block Elements */
-   for (i = 0x2E80; i <= 0xA4CF; i++) wide[i] = 1; /* CJK */
+   for (i = 0x0700; i <= 0x074F; i++) wide[i] = 1; /* Syriac                 */
+   for (i = 0x0800; i <= 0x083F; i++) wide[i] = 1; /* Samaritan (5.2)        */
+   for (i = 0x0900; i <= 0x0DFF; i++) wide[i] = 1; /* Indic                  */
+   for (i = 0x0F00; i <= 0x0FFF; i++) wide[i] = 1; /* Tibetan                */
+   for (i = 0x1100; i <= 0x11FF; i++) wide[i] = 1; /* Hangul Jamo            */
+   for (i = 0x1800; i <= 0x18AF; i++) wide[i] = 1; /* Mongolian              */
+   for (i = 0x1900; i <= 0x194F; i++) wide[i] = 1; /* Limbu                  */
+   for (i = 0x1980; i <= 0x19DF; i++) wide[i] = 1; /* New Tai Lue            */
+   for (i = 0x1A00; i <= 0x1A1F; i++) wide[i] = 1; /* Buginese               */
+   for (i = 0x1B00; i <= 0x1B7F; i++) wide[i] = 1; /* Balinese               */
+   for (i = 0x1B80; i <= 0x1BBF; i++) wide[i] = 1; /* Sundanese (5.1)        */
+   for (i = 0x1BC0; i <= 0x1BFF; i++) wide[i] = 1; /* Batak (6.0)            */
+   for (i = 0x1C00; i <= 0x1C4F; i++) wide[i] = 1; /* Lepcha (5.1)           */
+   for (i = 0x1CD0; i <= 0x1CFF; i++) wide[i] = 1; /* Vedic Extensions (5.2) */
+   for (i = 0x2E80; i <= 0xA4CF; i++) wide[i] = 1; /* CJK                    */
+   for (i = 0x1A20; i <= 0x1AAF; i++) wide[i] = 1; /* Tai Tham (5.2)         */
+   for (i = 0xA930; i <= 0xA95F; i++) wide[i] = 1; /* Rejang (5.1)           */
+   for (i = 0xA980; i <= 0xA9DF; i++) wide[i] = 1; /* Javanese (5.2)         */
+   for (i = 0xAA00; i <= 0xAA5F; i++) wide[i] = 1; /* Cham (5.1)             */
+   for (i = 0xAAE0; i <= 0xAAFF; i++) wide[i] = 1; /* Meetei Mayek Ext (6.0) */
+   for (i = 0xABC0; i <= 0xABFF; i++) wide[i] = 1; /* Meetei Mayek (5.2)     */
 
    wide[0x303F] = 0; /* CJK half-space fill */
 
-   for (i = 0xFF01; i <= 0xFF60; i++) wide[i] = 1; /* Fullwidth ASCII */
-   for (i = 0xFFE0; i <= 0xFFE6; i++) wide[i] = 1; /* Fullwidth Symbol */
-
-
    /*
       Determine whether or not the file is a Microsoft Windows Bitmap file.
       If it starts with 'B', 'M', assume it's a Windows Bitmap file.
@@ -324,11 +345,16 @@ int main(int argc, char *argv[]) {
                Original GNU Unifont format is four hexadecimal digit character
                code followed by a colon followed by a hex string.  Add support
                for codes beyond the Basic Multilingual Plane.
+
+               Unicode ranges from U+0000 to U+10FFFF, so print either a
+               4-digit or a 6-digit code point.  Note that this software
+               should support up to an 8-digit code point, extending beyond
+               the normal Unicode range, but this has not been fully tested.
             */
             if (uniplane > 0xff)
-               fprintf(outfp, "%06X%X%X:", uniplane, i, j);
+               fprintf(outfp, "%04X%X%X:", uniplane, i, j); // 6 digit code pt.
             else
-               fprintf(outfp, "%02X%X%X:", uniplane, i, j);
+               fprintf(outfp, "%02X%X%X:", uniplane, i, j); // 4 digit code pt.
             for (thisrow=0; thisrow<16; thisrow++) {
                /*
                   If second half is empty and we're not forcing this
