@@ -8,28 +8,29 @@
 
    Author: Paul Hardy, unifoundry <at> unifoundry.com, December 2007
    
-   
-    Copyright (C) 2007-2008 Paul Hardy
+   Copyright (C) 2007, 2008, 2013 Paul Hardy
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   LICENSE:
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+      This program is free software: you can redistribute it and/or modify
+      it under the terms of the GNU General Public License as published by
+      the Free Software Foundation, either version 2 of the License, or
+      (at your option) any later version.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+      This program is distributed in the hope that it will be useful,
+      but WITHOUT ANY WARRANTY; without even the implied warranty of
+      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+      GNU General Public License for more details.
+
+      You should have received a copy of the GNU General Public License
+      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#define MAXBUF 1000
+#define MAXBUF 256
 
 
 /*
@@ -65,7 +66,7 @@ char *hex[18]= {
 unsigned char hexbits[18][32]; /* The above digits converted into bitmap */
 
 unsigned unipage=0;        /* Unicode page number, 0x00..0xff */
-int flip=0;                /* transpose entire matrix as in Unicode book */
+int flip=1;                /* transpose entire matrix as in Unicode book */
 
 
 
@@ -74,7 +75,7 @@ int main(int argc, char *argv[]) {
    int i, j;                  /* loop variables                    */
    unsigned k0;               /* temp Unicode char variable        */
    unsigned swap;             /* temp variable for swapping values */
-   char inbuf[MAXBUF];        /* input buffer                      */
+   char inbuf[256];           /* input buffer                      */
 // unsigned headersize=0x28;  /* size of header (fixed in Windows) */
    unsigned filesize;         /* size of file in bytes             */
    unsigned bitmapsize;       /* size of bitmap image in bytes     */
@@ -102,7 +103,7 @@ int main(int argc, char *argv[]) {
          if (argv[i][0] == '-') {  /* this is an option argument */
             switch (argv[i][1]) {
                case 'f':  /* flip (transpose) glyphs in bitmap as in standard */
-                  flip = 1;
+                  flip = !flip;
                   break;
                case 'i':  /* name of input file */
                   infile = &argv[i][2];
@@ -327,14 +328,12 @@ int hex2bit(char *instring, unsigned char character[32][4]) {
    // width = (strlen(instring) - 1) >> 4; /* 16 hex digits per 8 bytes */
 
    if (strlen(instring) <= 34)  /* 32 + possible '\r', '\n' */
-     width = 0;
+      width = 0;
    else if (strlen(instring) <= 66)  /* 64 + possible '\r', '\n' */
       width = 1;
    else
       width = 4;
 
-   if (width > 1) width = 1; /* Disable quad-wide until fully implemented */
-
    k = (width > 1) ? 0 : 1;  /* if width < 3, start at index 1 else at 0 */
 
    for (i=8; i<24; i++) {  /* 16 rows per input character, rows 8..23 */
